module TortoiseLabs
  class Invoice
    attr_reader :items, :creation_ts, :payment_ts, :total, :user, :id
    
    def initialize(ihash)
      @creation_ts, @total = ihash["creation_ts"], ihash["total"]
      @payment_ts, @user = ihash["payment_ts"], ihash["user"]
      @id = ihash["invoice"]
      @items = Array.new
      
      ihash["items"].each do |itemhash|
        obj = Item.new(itemhash)
        @items << obj
      end
    end
    
    # Instance methods
    
    def to_s
      "Invoice ##{@id}"
    end
    
    # Class Methods
    
    def self.list
      result = TortoiseLabs::Client.get("/invoice/list")
      invoices = Array.new
      JSON.parse(result)["invoices"].each do |invoice|
        obj = self.new(invoice)
        invoices << obj
      end
      invoices
    end
    
    def self.add_credit(amount)
      response = TortoiseLabs::Client.post("/invoice/svccredit",
                                          {:creditamt => amount})
      return response.request.last_uri.to_s
    end
    
    def self.get(id)
      result = TortoiseLabs::Client.get("/invoice/#{id}")
      self.new(JSON.parse(result)["invoice"])
    end
  end
  
  class Item
    attr_reader :price, :btc_price, :description, :line_item, :invoice
    attr_reader :entry_ts, :service
    
    def initialize(ihash)
      @btc_price, @price = ihash["btc_price"], ihash["price"]
      @description, @line_item = ihash["description"], ihash["line_item"]
      @entry_ts, @invoice = ihash["entry_ts"], ihash["invoice"]
      @service = ihash["service"]
    end
  end
end