module TortoiseLabs
  
  module DNS
    
    # DNS zone class
    
    class Zone
      attr_reader :id, :name, :records, :user
      
      def initialize(zhash)
        @id, @name, @user = zhash["id"], zhash["name"], zhash["user"]
        @records = Array.new
        
        zhash["records"].each do |record|
          obj = Record.new(record)
          obj.zoneid = @id
          @records << obj
        end
      end
      
      # Instance Methods      
      
      def delete
        resp = TortoiseLabs::Client.get("/dns/zone/#{@id}/delete")
        Zone.list
      end
      
      def new_record(subdomain, type, content, ttl = 3600, prio = 0)
        resp = TortoiseLabs::Client.post("/dns/zone/#{@id}/record/new", 
           {:subdomain => subdomain, :type => type, :ttl => ttl,
            :prio => prio, :content => content})
        Zone.list[@name]
      end
      
      def to_s
        @name
      end
      
      # Class Methods
      
      def self.list
        response = TortoiseLabs::Client.get("/dns/zones").parsed_response
        json = JSON.parse(response)
        zones = Hash.new
        
        json["zones"].each do |zone|
          obj = self.new(zone)
          zones[obj.name] = obj
        end
        
        zones
      end
      
      def self.create(domain)
        TortoiseLabs::Client.post("/dns/zone/new", {:domain_name => domain})
        list = self.list
        if list.keys.include?(domain)
          return list[domain]
        else
          return false
        end
      end
    end
    
    # DNS record class
    
    class Record
      attr_reader :id, :name, :content, :prio, :ttl, :type
      attr_accessor :zoneid
      
      def initialize(rhash)
        @id, @name, @content = rhash["id"], rhash["name"], rhash["content"]
        @prio, @ttl, @type = rhash["prio"], rhash["ttl"], rhash["type"]
      end
      
      def modify(new_content, subdomain = @name)
        TortoiseLabs::Client.post("/dns/zone/#{@zoneid}/record/#{@id}",
            {:content => new_content, :subdomain => subdomain})
        Zone.list.values.select { |z| z.id == zoneid }[0]
      end
      
      def delete
        resp = TortoiseLabs::Client.get("/dns/zone/#{@zoneid}/record/#{@id}/delete")
        Zone.new(JSON.parse(resp)["zone"])
      end
      
      def to_s
        "#{@type}:#{@name}"
      end
    end
  end
end
      
      
