module TortoiseLabs
  module Support
    class Ticket
      attr_reader :closed_at, :department, :opened_at, :priority, :replies
      attr_reader :subject, :id, :user
      
      def initialize(thash)
        @closed_at, @department = thash["closed_at"], thash["department"]
        @opened_at, @priority = thash["opened_at"], thash["priority"]
        @subject, @user, @id = thash["subject"], thash["user"], thash["ticket"]
        @is_open = thash["is_open"]
        
        @replies = Array.new
        
        thash["replies"].each do |reply|
          obj = Reply.new(reply)
          @replies << obj
        end
      end
      
      # Instance Methods
      
      def close
        result = TortoiseLabs::Client.get("/support/ticket/#{@id}/close")
        Ticket.list
      end
      
      def open?
        @is_open
      end
      
      def reply(message)
        result = TortoiseLabs::Client.post("/support/ticket/#{@id}",
          {:message => message})
        Ticket.list
      end
      
      # Class Methods
      
      def self.list
        result = TortoiseLabs::Client.get("/support/tickets")
        tickets = Array.new
        JSON.parse(result)["tickets"].each do |tickethash|
          obj = Ticket.new(tickethash)
          tickets << obj
        end
        tickets
      end
      
      def self.create(subject, message)
        result = TortoiseLabs::Client.post("/support/ticket/new",
          {:subject => subject, :message => message})
        self.list
      end
    end
    
    class Reply
      attr_reader :message, :replied_at, :ticket, :user
      
      def initialize(rhash)
        @message, @replied_at = rhash["message"], rhash["replied_at"]
        @ticket, @user = rhash["ticket"], rhash["user"]
      end
    end
  end
end
        